==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/ClassHandler.h <==
// class gnu.java.beans.decoder.ClassHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class b7a97014acb60552 gnu_java_beans_decoder_ClassHandler
// @dep_class b0ac10a3c7037665 gnu_java_beans_decoder_SimpleHandler
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_SimpleHandler

#include "gnu/java/beans/decoder/SimpleHandler.h"

#ifndef _JC_gnu_java_beans_decoder_ClassHandler_H_
#define _JC_gnu_java_beans_decoder_ClassHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_ClassHandler$sub_refs	_jc_gnu_java_beans_decoder_ClassHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_ClassHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_ClassHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ClassHandler$refs	_jc_gnu_java_beans_decoder_ClassHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_ClassHandler$nonrefs	_jc_gnu_java_beans_decoder_ClassHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ClassHandler$object	_jc_gnu_java_beans_decoder_ClassHandler$object;

typedef const struct _jc_gnu_java_beans_decoder_ClassHandler$vmethods	_jc_gnu_java_beans_decoder_ClassHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_ClassHandler$vtable	_jc_gnu_java_beans_decoder_ClassHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_ClassHandler$vtype	_jc_gnu_java_beans_decoder_ClassHandler$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_ClassHandler$method$_init$7d8397207e40a3b4(_jc_env *, struct _jc_gnu_java_beans_decoder_ClassHandler$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_ClassHandler$method$parse$d4a2df662e34a121(_jc_env *, struct _jc_gnu_java_beans_decoder_ClassHandler$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_ClassHandler$method_info$parse$d4a2df662e34a121;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_ClassHandler$vmethods {
	struct _jc_java_lang_Object$object	*(*parse$d4a2df662e34a121)(_jc_env *, struct _jc_gnu_java_beans_decoder_ClassHandler$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_ClassHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_SimpleHandler$vmethods	gnu_java_beans_decoder_SimpleHandler;
	_jc_gnu_java_beans_decoder_ClassHandler$vmethods	gnu_java_beans_decoder_ClassHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_ClassHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_ClassHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ClassHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ClassHandler$refs {
    _jc_gnu_java_beans_decoder_ClassHandler$sub_refs	gnu_java_beans_decoder_ClassHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_refs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ClassHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ClassHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_nonrefs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_ClassHandler$sub_nonrefs	gnu_java_beans_decoder_ClassHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_ClassHandler$object {
	_jc_gnu_java_beans_decoder_ClassHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_ClassHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_ClassHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_ClassHandler$vtype _jc_gnu_java_beans_decoder_ClassHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_ClassHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_ClassHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_ClassHandler_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/ClassHandler.h <==
// class gnu.java.beans.decoder.ClassHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class b7a97014acb60552 gnu_java_beans_decoder_ClassHandler
// @dep_class b0ac10a3c7037665 gnu_java_beans_decoder_SimpleHandler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_SimpleHandler

#include "gnu/java/beans/decoder/SimpleHandler.h"

#ifndef _JC_gnu_java_beans_decoder_ClassHandler_H_
#define _JC_gnu_java_beans_decoder_ClassHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_ClassHandler$sub_refs	_jc_gnu_java_beans_decoder_ClassHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_ClassHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_ClassHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ClassHandler$refs	_jc_gnu_java_beans_decoder_ClassHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_ClassHandler$nonrefs	_jc_gnu_java_beans_decoder_ClassHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ClassHandler$object	_jc_gnu_java_beans_decoder_ClassHandler$object;

typedef const struct _jc_gnu_java_beans_decoder_ClassHandler$vmethods	_jc_gnu_java_beans_decoder_ClassHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_ClassHandler$vtable	_jc_gnu_java_beans_decoder_ClassHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_ClassHandler$vtype	_jc_gnu_java_beans_decoder_ClassHandler$vtype;

// Constructors
extern void _jc_gnu_java_beans_decoder_ClassHandler$method$_init$7d8397207e40a3b4(_jc_env *, struct _jc_gnu_java_beans_decoder_ClassHandler$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_beans_decoder_ClassHandler$method$parse$d4a2df662e34a121(_jc_env *, struct _jc_gnu_java_beans_decoder_ClassHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_ClassHandler$method_info$parse$d4a2df662e34a121;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_ClassHandler$vmethods {
	struct _jc_java_lang_Object$object	*(*parse$d4a2df662e34a121)(_jc_env *, struct _jc_gnu_java_beans_decoder_ClassHandler$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_ClassHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_SimpleHandler$vmethods	gnu_java_beans_decoder_SimpleHandler;
	_jc_gnu_java_beans_decoder_ClassHandler$vmethods	gnu_java_beans_decoder_ClassHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_ClassHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_ClassHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ClassHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ClassHandler$refs {
    _jc_gnu_java_beans_decoder_ClassHandler$sub_refs	gnu_java_beans_decoder_ClassHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_refs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ClassHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ClassHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_SimpleHandler$sub_nonrefs	gnu_java_beans_decoder_SimpleHandler;
    _jc_gnu_java_beans_decoder_ClassHandler$sub_nonrefs	gnu_java_beans_decoder_ClassHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_ClassHandler$object {
	_jc_gnu_java_beans_decoder_ClassHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_ClassHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_ClassHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_ClassHandler$vtype _jc_gnu_java_beans_decoder_ClassHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_ClassHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_ClassHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_ClassHandler_H_ */
